@@ -5,3 +5,6 @@ class Colour(Enum):
     YELLOW = "\033[93m"
     RED = "\033[91m"
     RESET = "\033[0m"
+
+    def __str__(self) -> str:
+        return str(self.value)
