@@ -2,7 +2,7 @@ from ... import error
 from ...model.thread_item import ThreadItem
 from ...model.timer import TimerObject
 
-def try_get_thread_item_and_index(timer: TimerObject, thread: str) -> tuple[ThreadItem, int]:
+def try_get_thread_item_and_index(timer: TimerObject, thread: str) -> tuple[ThreadItem, int] | tuple[None, None]:
     try:
         index_counter = 0
         for thread_item in timer.threads:
@@ -12,13 +12,14 @@ def try_get_thread_item_and_index(timer: TimerObject, thread: str) -> tuple[Thre
                 index_counter += 1
         return None, None
     except Exception:
-        error.message_for_action(f"in the Timer's lookup module", thread = thread)
+        error.message_for_action("in the Timer's lookup module", thread = thread)
+        return None, None
 
 def add(timer: TimerObject, thread: str, start_time: int, decimals: int) -> None:
     try:
         timer.threads.append(ThreadItem(name = thread, start_time = start_time, decimals = decimals))
     except Exception:
-        error.message_for_action(f"when trying to add entry to the Timer's thread list", thread = thread)
+        error.message_for_action("when trying to add entry to the Timer's thread list", thread = thread)
 
 def remove(timer: TimerObject, entry_index: int) -> None:
     try:
